aboutsummaryrefslogtreecommitdiffstats
path: root/build
diff options
context:
space:
mode:
authorJoas Schilling <coding@schilljs.com>2023-11-23 10:06:38 +0100
committerJoas Schilling <coding@schilljs.com>2023-11-23 10:06:38 +0100
commit7f3ebb4e73d05bcdfb23b93003e7cd22b9272a05 (patch)
treebe4e48f290483a7fdda0011f361e21dee8ad84e6 /build
parent09879700aa5a1ff354ce1366638da56720b4aa08 (diff)
downloadnextcloud-server-7f3ebb4e73d05bcdfb23b93003e7cd22b9272a05.tar.gz
nextcloud-server-7f3ebb4e73d05bcdfb23b93003e7cd22b9272a05.zip
Test against stable28 branches
Signed-off-by: Joas Schilling <coding@schilljs.com>
Diffstat (limited to 'build')
-rwxr-xr-xbuild/update-apps.sh8
-rwxr-xr-xbuild/update.sh6
2 files changed, 7 insertions, 7 deletions
diff --git a/build/update-apps.sh b/build/update-apps.sh
index e4611a79aff..9b7a8313802 100755
--- a/build/update-apps.sh
+++ b/build/update-apps.sh
@@ -1,14 +1,14 @@
#!/bin/bash
# Update Nextcloud apps from latest git master
# For local development environment
# Use from Nextcloud server folder with `./build/update-apps.sh`
#
# It automatically:
# - goes through all apps which are not shipped via server
# - shows the app name in bold and uses whitespace for separation
# - changes to master and pulls quietly
# - shows the 3 most recent commits for context
# - removes branches merged into master
# - … could even do the build steps if they are consistent for the apps (like `make`)
-find apps* -maxdepth 2 -name .git -exec sh -c 'cd {}/../ && printf "\n\033[1m${PWD##*/}\033[0m\n" && git checkout master && git pull --quiet -p && git --no-pager log -3 --pretty=format:"%h %Cblue%ar%x09%an %Creset%s" && printf "\n" && git branch --merged master | grep -v "master$" | xargs git branch -d && cd ..' \;
+find apps* -maxdepth 2 -name .git -exec sh -c 'cd {}/../ && printf "\n\033[1m${PWD##*/}\033[0m\n" && git checkout stable28 && git pull --quiet -p && git --no-pager log -3 --pretty=format:"%h %Cblue%ar%x09%an %Creset%s" && printf "\n" && git branch --merged stable28 | grep -v "stable28$" | xargs git branch -d && cd ..' \;
@@ -1,14 +1,14 @@
#!/bin/bash
-# Update Nextcloud apps from latest git master
+# Update Nextcloud apps from latest git stable28
# For local development environment
# Use from Nextcloud server folder with `./build/update-apps.sh`
@@ -1,14 +1,14 @@
# - goes through all apps which are not shipped via server
# - shows the app name in bold and uses whitespace for separation
-# - changes to master and pulls quietly
+# - changes to stable28 and pulls quietly
# - shows the 3 most recent commits for context
@@ -1,14 +1,14 @@
# - shows the 3 most recent commits for context
-# - removes branches merged into master
+# - removes branches merged into stable28
# - … could even do the build steps if they are consistent for the apps (like `make`)
diff --git a/build/update.sh b/build/update.sh
index 3a3d2eac5dc..e5a1196e13f 100755
--- a/build/update.sh
+++ b/build/update.sh
@@ -1,15 +1,15 @@
#!/bin/bash
# Update Nextcloud server and apps from latest git master
# For local development environment
# Use from Nextcloud server folder with `./build/update.sh`
# Update server
printf "\n\033[1m${PWD##*/}\033[0m\n"
-git checkout master
+git checkout stable28
git pull --quiet -p
git --no-pager log -3 --pretty=format:"%h %Cblue%ar%x09%an %Creset%s"
printf "\n"
-git branch --merged master | grep -v "master$" | xargs git branch -d
+git branch --merged stable28 | grep -v "stable28$" | xargs git branch -d
git submodule update --init
# Update apps
@@ -1,15 +1,15 @@
#!/bin/bash
-# Update Nextcloud server and apps from latest git master
+# Update Nextcloud server and apps from latest git stable28
# For local development environment
# Use from Nextcloud server folder with `./build/update.sh`